Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1938)

Unified Diff: ash/shell_init_params.h

Issue 2808723004: Renames WmShell to ShellPort (Closed)
Patch Set: cleanup Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/shell_init_params.h
diff --git a/ash/shell_init_params.h b/ash/shell_init_params.h
index d2f01e6b07661690b63aba9210b4b5f458c6f13d..8b3d8cb1c90fddfd4f7ad8257251e3cc172f0552 100644
--- a/ash/shell_init_params.h
+++ b/ash/shell_init_params.h
@@ -22,11 +22,12 @@ class ContextFactory;
namespace ash {
class ShellDelegate;
+class ShellPort;
struct ASH_EXPORT ShellInitParams {
// Shell takes ownership of |wm_shell|, if null WmShellAura is created.
James Cook 2017/04/10 22:00:41 nit: |shell_port|. Also, is the next line still tr
sky 2017/04/10 22:16:25 Once ash is the default and the classic code isn't
// TODO(sky): temporary, will eventually go away.
- WmShell* wm_shell = nullptr;
+ ShellPort* shell_port = nullptr;
// Shell takes ownership of |primary_window_tree_host|. This is only used
// by mash.
aura::WindowTreeHostMus* primary_window_tree_host = nullptr;
@@ -22,11 +22,12 @@ class ContextFactory;
struct ASH_EXPORT ShellInitParams {
- // Shell takes ownership of |wm_shell|, if null WmShellAura is created.
+ // Shell takes ownership of |wm_shell|, if null ShellPortClassic is created.
James Cook 2017/04/10 22:00:41 nit: |shell_port|. Also, is the next line still tr
sky 2017/04/10 22:16:25 Once ash is the default and the classic code isn't

Powered by Google App Engine
This is Rietveld 408576698